---
title: <span class="badge builder"></span> PointsConfig
---
# <span class="badge builder"></span> PointsConfig

## Constructor

```python
PointsConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.PointsConfig
```

### <span class="badge object-method"></span> point_color

```python
def point_color(point_color: str) -> typing.Self
```

### <span class="badge object-method"></span> point_size

```python
def point_size(point_size: float) -> typing.Self
```

### <span class="badge object-method"></span> point_symbol

```python
def point_symbol(point_symbol: str) -> typing.Self
```

### <span class="badge object-method"></span> show_points

```python
def show_points(show_points: common.VisibilityMode) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [PointsConfig](./object-PointsConfig.md)
